==> meld-tools-model-0.1.2-sources.jar: ch/raffael/meldioc/model/InconsistentModelException.java <==
/*
 *  Copyright (c) 2019 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.model;

import javax.annotation.Nullable;

/**
 * Thrown when some internal consistency check failed. If this exception is
 * thrown, it's a bug.
 */
public class InconsistentModelException extends RuntimeException {

  private final CElement<?, ?> element;

  public InconsistentModelException(String message, CElement<?, ?> element) {
    this(message, element, null);
  }

  public InconsistentModelException(String message, CElement<?, ?> element, @Nullable Throwable cause) {
    super(message + ": " + element, cause);
    this.element = element;
  }

  InconsistentModelException(String message, _CElement<?, ?> element) {
    this(message, (CElement<?, ?>)element, null);
  }

  InconsistentModelException(String message, _CElement<?, ?> element, @Nullable Throwable cause) {
    this(message, (CElement<?, ?>)element, cause);
  }

  public CElement<?, ?> getElement() {
    return element;
  }
}

==> meld-tools-model-0.1.6-sources.jar: ch/raffael/meldioc/model/InconsistentModelException.java <==
/*
 *  Copyright (c) 2021 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.model;

import javax.annotation.Nullable;

/**
 * Thrown when some internal consistency check failed. If this exception is
 * thrown, it's a bug.
 */
public class InconsistentModelException extends RuntimeException {

  private final SrcElement<?, ?> element;

  public InconsistentModelException(String message, SrcElement<?, ?> element) {
    this(message, element, null);
  }

  public InconsistentModelException(String message, SrcElement<?, ?> element, @Nullable Throwable cause) {
    super(message + ": " + element, cause);
    this.element = element;
  }

  InconsistentModelException(String message, _SrcElement<?, ?> element) {
    this(message, (SrcElement<?, ?>)element, null);
  }

  InconsistentModelException(String message, _SrcElement<?, ?> element, @Nullable Throwable cause) {
    this(message, (SrcElement<?, ?>)element, cause);
  }

  public SrcElement<?, ?> getElement() {
    return element;
  }
}
